import os
from .exceptions import OverdueError
from .exceptions import OverdueWarning
from .helpers.is_production import is_production
from datetime import datetime as dt
from typing import Union
from warnings import warn

DATE_FORMAT = "%Y-%m-%d"


def todo_or_die(message: str, by: Union[str, dt] = None) -> None:
    if not by:
        __die(message)

    if isinstance(by, str):
        by = dt.strptime(by, DATE_FORMAT)

    if dt.now() > by:
        __die(message, by.strftime(DATE_FORMAT))


def __die(message: str, date: str = "") -> None:
    if is_production():
        warn(OverdueWarning(message, date))
    else:
        raise OverdueError(message, date)



import os

def is_production() -> bool:
  return os.getenv('PRODUCTION') == 'true' \
          or os.getenv('DJANGO_ENVIRONMENT') == 'production' \
          or os.getenv('ENVIRONMENT') == 'production' \
          or os.getenv('FLASK_ENV') == 'production'
          


from .helpers.generate_message import generate_message
from warnings import warn


class OverdueError(Exception):
    def __init__(self, message: str, date: str = ""):
        super().__init__(generate_message(message, date))

class OverdueWarning(Warning):
    def __init__(self, message: str, date: str = ""):
        self.output = generate_message(message, date)
    
    def __str__(self):
        return repr(self.output)


import io
import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

meta = {}
with io.open('./src/todo_or_die/version.py', encoding='utf-8') as f:
    exec(f.read(), meta)

setuptools.setup(
    name="todo-or-die-python",
    version=meta['__version__'],
    author="Brandon Walsh",
    author_email="bmwalshy@gmail.com",
    description="Halt code if your TODO is passed due",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/walshyb/todo-or-die-python",
    project_urls={
        "Bug Tracker": "https://github.com/walshyb/todo-or-die-python/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
)